@@ -6,13 +6,13 @@ import numpy as np
 import concurrent.futures as cf
 
 from arize.api import Client
-from arize.types import ModelTypes
+from arize.utils.types import ModelTypes
 
 ITERATIONS = 1
 NUM_RECORDS = 100
 
 arize = Client(
-    organization_key=os.environ.get("ARIZE_ORG_KEY"),
+    space_key=os.environ.get("ARIZE_SPACE_KEY"),
     api_key=os.environ.get("ARIZE_API_KEY"),
 )
 
